package com.ruoyi.mall.mapper;

import java.util.List;
import com.ruoyi.mall.domain.BusinessTutorial;

/**
 * 使用教程Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-23
 */
public interface BusinessTutorialMapper 
{
    /**
     * 查询使用教程
     * 
     * @param tutorialId 使用教程主键
     * @return 使用教程
     */
    public BusinessTutorial selectBusinessTutorialByTutorialId(Long tutorialId);

    /**
     * 查询使用教程列表
     * 
     * @param businessTutorial 使用教程
     * @return 使用教程集合
     */
    public List<BusinessTutorial> selectBusinessTutorialList(BusinessTutorial businessTutorial);

    /**
     * 新增使用教程
     * 
     * @param businessTutorial 使用教程
     * @return 结果
     */
    public int insertBusinessTutorial(BusinessTutorial businessTutorial);

    /**
     * 修改使用教程
     * 
     * @param businessTutorial 使用教程
     * @return 结果
     */
    public int updateBusinessTutorial(BusinessTutorial businessTutorial);

    /**
     * 删除使用教程
     * 
     * @param tutorialId 使用教程主键
     * @return 结果
     */
    public int deleteBusinessTutorialByTutorialId(Long tutorialId);

    /**
     * 批量删除使用教程
     * 
     * @param tutorialIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBusinessTutorialByTutorialIds(Long[] tutorialIds);
}
